==> jcloud-0.2.15.tar.gz: jcloud-0.2.15/jcloud/parsers/remove.py <==
from .helper import _chf
from ..constants import Phase, Resources


def set_remove_resource_parser(subparser, parser_prog):

    if Resources.Flow in parser_prog:
        remove_parser = subparser.add_parser(
            'remove',
            help='Remove Flow(s). If `all` is passed it removes Flows in `Serving` or `Failed` phase.',
            formatter_class=_chf,
        )
        _set_remove_flow_parser(remove_parser)
    else:
        resource = Resources.Job if Resources.Job in parser_prog else Resources.Secret
        remove_parser = subparser.add_parser(
            'remove',
            help=f'Remove a {resource.title()} from a Flow.',
            formatter_class=_chf,
        )
        _set_remove_resource_parser(remove_parser, resource)


def _set_remove_flow_parser(remove_parser):
    remove_parser.add_argument(
        '--phase',
        help='The phase to filter flows on for removal',
        type=str,
        choices=[s.value for s in Phase if s.value != ''] + ['All'],
    )

    remove_parser.add_argument(
        'flows',
        nargs="*",
        help='The string ID of a flow for single removal, '
        'or a list of space seperated string IDs for multiple removal, '
        'or string \'all\' for deleting ALL SERVING flows.',
    )


def _set_remove_resource_parser(remove_parser, resource):
    remove_parser.add_argument(
        'name',
        type=str,
        help=f'The name of the {resource.title()} to remove.',
    )

    remove_parser.add_argument(
        'flow',
        type=str,
        help='The string ID of the Flow.',
    )

==> jcloud-0.2.17.dev2.tar.gz: jcloud-0.2.17.dev2/jcloud/parsers/remove.py <==
from .helper import _chf
from ..constants import Phase, Resources


def set_remove_resource_parser(subparser, parser_prog):

    if Resources.Flow in parser_prog:
        remove_parser = subparser.add_parser(
            'remove',
            help='Remove Flow(s). If `all` is passed it removes Flows in `Serving` or `Failed` phase.',
            formatter_class=_chf,
        )
        _set_remove_flow_parser(remove_parser)
    elif Resources.Deployment in parser_prog:
        remove_parser = subparser.add_parser(
            'remove',
            help='Remove Deployment(s). If `all` is passed it removes Deployments in `Serving` or `Failed` phase.',
            formatter_class=_chf,
        )
        _set_remove_deployment_parser(remove_parser)
    else:
        resource = Resources.Job if Resources.Job in parser_prog else Resources.Secret
        remove_parser = subparser.add_parser(
            'remove',
            help=f'Remove a {resource.title()} from a Flow.',
            formatter_class=_chf,
        )
        _set_remove_resource_parser(remove_parser, resource)


def _set_remove_flow_parser(remove_parser):
    remove_parser.add_argument(
        '--phase',
        help='The phase to filter flows on for removal',
        type=str,
        choices=[s.value for s in Phase if s.value != ''] + ['All'],
    )

    remove_parser.add_argument(
        'flows',
        nargs="*",
        help='The string ID of a flow for single removal, '
        'or a list of space separated string IDs for multiple removal, '
        'or string \'all\' for deleting ALL SERVING flows.',
    )


def _set_remove_deployment_parser(remove_parser):
    remove_parser.add_argument(
        '--phase',
        help='The phase to filter deployments on for removal',
        type=str,
        choices=[s.value for s in Phase if s.value != ''] + ['All'],
    )

    remove_parser.add_argument(
        'deployments',
        nargs="*",
        help='The string ID of a deployment for single removal, '
        'or a list of space separated string IDs for multiple removal, '
        'or string \'all\' for deleting ALL SERVING deployments.',
    )


def _set_remove_resource_parser(remove_parser, resource):
    remove_parser.add_argument(
        'name',
        type=str,
        help=f'The name of the {resource.title()} to remove.',
    )

    remove_parser.add_argument(
        'flow',
        type=str,
        help='The string ID of the Flow.',
    )
